@@ -1,13 +1,11 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-"""ADS-B Cursor-on-Target Gateway Commands."""
+"""ADSBXCOT Commands."""
 
-import aiohttp
 import argparse
 import asyncio
 import collections
-import concurrent
 import configparser
 import logging
 import os
@@ -25,14 +23,15 @@ else:
     from asyncio import _get_running_loop as get_running_loop
 
 __author__ = "Greg Albrecht W2GMD <oss@undef.net>"
-__copyright__ = "Copyright 2021 Orion Labs, Inc."
+__copyright__ = "Copyright 2022 Greg Albrecht"
 __license__ = "Apache License, Version 2.0"
 
 
 async def main(opts):
     tx_queue: asyncio.Queue = asyncio.Queue()
     rx_queue: asyncio.Queue = asyncio.Queue()
-    cot_url: urllib.parse.ParseResult = urllib.parse.urlparse(opts.get("COT_URL"))
+    cot_url: urllib.parse.ParseResult = urllib.parse.urlparse(
+        opts.get("COT_URL"))
 
     # Create our CoT Event Queue Worker
     reader, writer = await pytak.protocol_factory(cot_url)
@@ -44,7 +43,7 @@ async def main(opts):
     await tx_queue.put(pytak.hello_event("adsbxcot"))
 
     done, pending = await asyncio.wait(
-        set([message_worker.run(), read_worker.run(), write_worker.run()]),
+        {message_worker.run(), read_worker.run(), write_worker.run()},
         return_when=asyncio.FIRST_COMPLETED)
 
     for task in done:
@@ -56,14 +55,18 @@ def cli():
 
     parser = argparse.ArgumentParser()
 
-    parser.add_argument("-c", "--CONFIG_FILE", dest="CONFIG_FILE", default="config.ini", type=str)
     parser.add_argument(
-        "-d", "--DEBUG", dest="DEBUG", default=False, action="store_true", help="Enable DEBUG logging")
+        "-c", "--CONFIG_FILE", dest="CONFIG_FILE", default="config.ini",
+        type=str)
+    parser.add_argument(
+        "-d", "--DEBUG", dest="DEBUG", default=False, action="store_true",
+        help="Enable DEBUG logging")
     parser.add_argument(
         '-U',
         '--COT_URL',
         dest="COT_URL",
-        help='URL to CoT Destination. Must be a URL, e.g. tcp:1.2.3.4:1234 or tls:...:1234, etc.'
+        help='URL to CoT Destination. Must be a URL, e.g. '
+             'tcp:1.2.3.4:1234 or tls:...:1234, etc.'
     )
     parser.add_argument(
         '-S',
@@ -107,7 +110,8 @@ def cli():
 
     # Combined command-line args with config file:
     if "adsbxcot" in config:
-        combined_config = collections.ChainMap(cli_args, os.environ, config["adsbxcot"])
+        combined_config = collections.ChainMap(
+            cli_args, os.environ, config["adsbxcot"])
     else:
         combined_config = collections.ChainMap(cli_args, os.environ)
 
@@ -116,15 +120,18 @@ def cli():
         logging.info("Reading FILTER_CONFIG from %s", filter_config)
         filters = configparser.ConfigParser()
         filters.read(filter_config)
-        combined_config = collections.ChainMap(combined_config, {"FILTERS": filters})
+        combined_config = collections.ChainMap(
+            combined_config, {"FILTERS": filters})
 
     if not combined_config.get("COT_URL"):
-        print("Please specify a CoT Destination URL, for example: '-U tcp:takserver.example.com:8087'")
+        print("Please specify a CoT Destination URL, for example: "
+              "'-U tcp:takserver.example.com:8087'")
         print("See -h for help.")
         sys.exit(1)
 
     if not combined_config.get("ADSBX_URL"):
-        print("Please specify a ADSB Exchange Source URL, for example: '-A https://adsbx.com/...'")
+        print("Please specify a ADSB Exchange Source URL, for example: "
+              "'-A https://adsbx.com/...'")
         print("See -h for help.")
         sys.exit(1)
 
